@@ -1,6 +1,6 @@
 package Email::Sender::Simple;
 # ABSTRACT: the simple interface for sending mail with Sender
-$Email::Sender::Simple::VERSION = '1.300027';
+$Email::Sender::Simple::VERSION = '1.300028';
 use Moo;
 with 'Email::Sender::Role::CommonSending';
 
@@ -47,7 +47,7 @@ use Try::Tiny;
       $arg{lc $new_key} = $ENV{$key};
     }
 
-    return Email::Sender::Util->_easy_transport($transport_class, \%arg);
+    return Email::Sender::Util->easy_transport($transport_class, \%arg);
   }
 
   sub default_transport {
@@ -179,7 +179,7 @@ Email::Sender::Simple - the simple interface for sending mail with Sender
 
 =head1 VERSION
 
-version 1.300027
+version 1.300028
 
 =head1 SEE INSTEAD
 
