@@ -1,6 +1,6 @@
 package Email::Sender::Transport::Wrapper;
 # ABSTRACT: a mailer to wrap a mailer for mailing mail
-$Email::Sender::Transport::Wrapper::VERSION = '1.300027';
+$Email::Sender::Transport::Wrapper::VERSION = '1.300028';
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -47,7 +47,7 @@ sub BUILDARGS {
       $arg{$key} = delete $href->{"transport_arg_$key"};
     }
 
-    $href->{transport} = Email::Sender::Util->_easy_transport($class, \%arg);
+    $href->{transport} = Email::Sender::Util->easy_transport($class, \%arg);
   }
 
   return $href;
@@ -68,7 +68,7 @@ Email::Sender::Transport::Wrapper - a mailer to wrap a mailer for mailing mail
 
 =head1 VERSION
 
-version 1.300027
+version 1.300028
 
 =head1 DESCRIPTION
 
