@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::Sender::Util;
 # ABSTRACT: random stuff that makes Email::Sender go
-$Email::Sender::Util::VERSION = '1.300027';
+$Email::Sender::Util::VERSION = '1.300028';
 use Email::Address;
 use Email::Sender::Failure;
 use Email::Sender::Failure::Permanent;
@@ -67,10 +67,23 @@ sub _failure {
   });
 }
 
-sub _easy_transport {
+#pod =method easy_transport
+#pod
+#pod   my $transport = Email::Sender::Util->easy_transport($class => \%arg);
+#pod
+#pod This takes the name of a transport class and a set of args to new.  It returns
+#pod an Email::Sender::Transport object of that class.
+#pod
+#pod C<$class> is rewritten to C<Email::Sender::Transport::$class> unless it starts
+#pod with an equals sign (C<=>) or contains a colon.  The equals sign, if present,
+#pod will be removed.
+#pod
+#pod =cut
+
+sub easy_transport {
   my ($self, $transport_class, $arg) = @_;
 
-  if ($transport_class !~ tr/://) {
+  if ($transport_class =~ s/^=// or $transport_class !~ tr/://) {
     $transport_class = "Email::Sender::Transport::$transport_class";
   }
 
@@ -92,7 +105,20 @@ Email::Sender::Util - random stuff that makes Email::Sender go
 
 =head1 VERSION
 
-version 1.300027
+version 1.300028
+
+=head1 METHODS
+
+=head2 easy_transport
+
+  my $transport = Email::Sender::Util->easy_transport($class => \%arg);
+
+This takes the name of a transport class and a set of args to new.  It returns
+an Email::Sender::Transport object of that class.
+
+C<$class> is rewritten to C<Email::Sender::Transport::$class> unless it starts
+with an equals sign (C<=>) or contains a colon.  The equals sign, if present,
+will be removed.
 
 =head1 AUTHOR
 
